@@ -1,15 +1,18 @@
 /**
- * $Id: queue.h,v 1.2 2004/06/21 16:44:17 jklein Exp $
+ * $Id: queue.h,v 1.3 2004/06/26 06:58:13 jklein Exp $
  * $Author: jklein $
  * $Log: queue.h,v $
+ * Revision 1.3  2004/06/26 06:58:13  jklein
+ * small fix in each header files.
+ *
  * Revision 1.2  2004/06/21 16:44:17  jklein
  * Added iterator.
  *
  */
 
 
-#ifndef _SC_QUEUE_H_
-#define _SC_QUEUE_H_
+#ifndef _SCALE_QUEUE_H_
+#define _SCALE_QUEUE_H_
 
 #include "scale/commons.h"
 #include "scale/list.h"
@@ -27,4 +30,4 @@ spointer		s_queue_front(squeue_t *);
 
 
 
-#endif /* _SC_QUEUE_H_ */
+#endif /* _SCALE_QUEUE_H_ */
