@@ -1,7 +1,7 @@
 
 #include "scale/btree.h"
 #include "scale/alloc.h"
-
+#include <stdio.h>
 
 static sbtree_node_t *
 _s_node_alloc(spointer key, spointer contents)
@@ -85,6 +85,7 @@ s_btree_add(sbtree_t *btree, spointer key, spointer conts)
 		pnode->rnode = cnode;
 	else
 		pnode->lnode = cnode;
+
 	++btree->count;
 }
 
@@ -112,33 +113,40 @@ s_btree_remove(sbtree_t *btree, const spointer key)
 	sint cmp;
 	sbtree_node_t *pnode, *cnode, *tnode;
 	spointer contents;
-	sboolean save_right = true;
+	sboolean save_right;
 
 	btree->end->key = key;
 	pnode = btree->head;
 	cnode = btree->head->rnode;
+	save_right = true;
 
 	while ((cmp = btree->compare(key, cnode->key)) != 0) {
 		pnode = cnode;
-		cnode = (cmp > 0)?pnode->rnode:pnode->lnode;
+		cnode = (cmp > 0)?cnode->rnode:cnode->lnode;
 		save_right = (cmp > 0);
 	}
 
 	contents = cnode->contents;
 	tnode = cnode;
 
-	if (cnode->rnode == btree->end) {
-		cnode = cnode->lnode;
+	/* $B;R$r;}$?$J$$$+!":8$N;R$N$_;}$D$H$-$O(Bcnode$B$O:8$N;R$+(Bend$B$r;}$D(B */
+	if (tnode->rnode == btree->end) {
+		cnode = tnode->lnode;
 	}
-	else if (cnode->rnode->lnode == btree->end) {
-		cnode = cnode->rnode;
+	else if (tnode->lnode == btree->end) {
+		cnode = tnode->rnode;
+	}
+	/* $B1&$N;R$,:8$N;R$r;}$?$J$$;~$O!"(B */
+	else if (tnode->rnode->lnode == btree->end) {
+		cnode = tnode->rnode;
 		cnode->lnode = tnode->lnode;
 	}
 	else {
 		sbtree_node_t *nextnode; /* smallest node in 'cnode'. */
-		nextnode = cnode->lnode;
+		nextnode = cnode->rnode;
 		while (nextnode->lnode->lnode != btree->end)
 			nextnode = nextnode->lnode;
+
 		cnode = nextnode->lnode;
 		nextnode->lnode = cnode->rnode;
 		cnode->lnode = tnode->lnode;
