@@ -69,5 +69,5 @@ s_buffer_rcompare(const spointer p1, const spointer p2)
 sint8
 s_pointer_compare(const spointer p1, const spointer p2)
 {
-	return p1 - p2;
+	return (long)p1 - (long)p2;
 }
