@@ -5,6 +5,28 @@
 
 #define DEF_HEAP_SIZE 64
 
+
+static void
+_s_heap_grouth(sheap_t *heap, size_t tsize)
+{
+	spointer *p;
+
+	if (heap->memsize >= tsize)
+		return; /* nothiong to do. */
+
+	heap->array = (spointer *)s_reallocn(heap->array,
+										 sizeof(spointer) * heap->memsize,
+										 sizeof(spointer) * tsize);
+
+	/* clean the new memory */
+	p = heap->array + heap->memsize;
+	memset(p, 0x00, tsize - heap->memsize);
+
+	heap->memsize = tsize;
+}
+
+
+
 sheap_t *
 s_heap_alloc(sc_compf_t compare)
 {
@@ -17,7 +39,8 @@ s_heap_allocn(sc_compf_t compare, size_t inisize)
 {
 	sheap_t *heap;
 
-	if (inisize <= 1)
+	/* we have to increment the inisize. because we are not using index=0. */
+	if (++inisize <= 1)
 		inisize = 2;
 
 	heap = typed_malloc(sheap_t);
@@ -45,6 +68,9 @@ s_heap_push(sheap_t *heap, spointer contents)
 	size_t pindex, cindex;
 	spointer temp;
 
+	if (heap->next_index > heap->memsize - 1)
+		_s_heap_grouth(heap, heap->memsize * 2);
+
 	heap->array[heap->next_index] = contents;
 
 	cindex = heap->next_index;
@@ -61,13 +87,13 @@ s_heap_push(sheap_t *heap, spointer contents)
 	++heap->next_index;
 }
 
-
+#include <stdio.h>
 spointer
 s_heap_pop(sheap_t *heap)
 {
 	spointer contents;
 	spointer temp;
-	size_t pindex, lindex, rindex, tindex;
+	size_t pind, lind, rind, tind;
 
 	if (s_heap_size(heap) == 0)
 		return NULL;
@@ -80,35 +106,35 @@ s_heap_pop(sheap_t *heap)
 	heap->array[1] = heap->array[heap->next_index];
 	heap->array[heap->next_index] = NULL;
 
-	pindex = 1;
+	pind = 1;
 	while (1) {
-		lindex = HEAP_LCHILD_INDEX(pindex);
-		rindex = HEAP_RCHILD_INDEX(pindex);
+		lind = HEAP_LCHILD_INDEX(pind);
+		rind = HEAP_RCHILD_INDEX(pind);
 
-		/* which is bigger. left or right?
-		 * if right-node wasn't NULL, left-node is not too.
+		/* Chose the lager node.
+		   Remember if right-node wasn't NULL, left-node isn't too.
 		 */
-		if (heap->array[rindex] == NULL) {
-			if (heap->array[lindex] == NULL)
-				tindex = 0;
+		if (rind >= heap->count || heap->array[rind] == NULL) {
+			if (lind >= heap->count || heap->array[lind] == NULL)
+				tind = 0;
 			else
-				tindex = lindex;
+				tind = lind;
 		}
 		else {
-			tindex = (heap->compare(heap->array[lindex],
-									heap->array[rindex]) > 0)?lindex:rindex;
+			tind = (heap->compare(heap->array[lind],
+									heap->array[rind]) > 0)?lind:rind;
 		}
 
-		if (tindex == 0 ||
-			heap->compare(heap->array[tindex], heap->array[pindex]) <= 0)
+		if (tind == 0 ||
+			heap->compare(heap->array[tind], heap->array[pind]) <= 0)
 			break;
 
 		/* swap */
-		temp = heap->array[tindex];
-		heap->array[tindex] = heap->array[pindex];
-		heap->array[pindex] = temp;
+		temp = heap->array[tind];
+		heap->array[tind] = heap->array[pind];
+		heap->array[pind] = temp;
 
-		pindex = tindex;
+		pind = tind;
 	}
 	
 	return contents;
@@ -130,13 +156,13 @@ s_heap_size(sheap_t *heap)
 
 
 spointer
-s_heap_get(sheap_t *heap, size_t index)
+s_heap_get(sheap_t *heap, size_t ind)
 {
 	/* remember array index in heap-array is starting from 1. */
-	++index;
+	++ind;
 
-	if (index >= s_heap_size(heap))
+	if (ind >= s_heap_size(heap))
 		return NULL;
 	else
-		return heap->array[index];
+		return heap->array[ind];
 }
