@@ -1,7 +1,13 @@
 /*
- * $Id: sc_vector.c,v 1.7 2004/07/10 17:04:48 jklein Exp $
+ * $Id: sc_vector.c,v 1.9 2004/07/22 17:27:56 jklein Exp $
  * $Author: jklein $
  * $Log: sc_vector.c,v $
+ * Revision 1.9  2004/07/22 17:27:56  jklein
+ * few changes in stack.h
+ *
+ * Revision 1.8  2004/07/11 04:06:07  jklein
+ * fixed s_vector_sort.
+ *
  * Revision 1.7  2004/07/10 17:04:48  jklein
  * Added few function to sxarray_t.
  *
@@ -34,8 +40,7 @@ _s_vector_grouth(svector_t *vect, size_t tsize)
 	if (vect->memsize >= tsize)
 		return; /* nothiong to do. */
 
-	vect->array = (spointer *)s_reallocn(vect->array,
-										 vect->memsize,
+	vect->array = (spointer *)s_reallocn(vect->array, vect->memsize,
 										 sizeof(spointer)*tsize);
 	vect->memsize = tsize;
 }
@@ -189,25 +194,6 @@ _s_array_dump(const char *prmpt, spointer list[], int low, int high)
 }
 
 
-/**
- * list$B$N@hF,Fs$D$N%f%K!<%/$JMWAG$N$&$ABg$-$$J}$N%$%s%G%C%/%9$rJV$9!#(B
- * $B$9$Y$F$NMWAG$,Ey$7$$$H$-$O(B-1$B$rJV$9!#(B
- */
-static int
-_s_vector_qsort_pivot(spointer list[], int low, int high, sc_compf_t cmpf)
-{
-	int k = low + 1;
-
-	while (k <= high && cmpf(list[low], list[k]) == 0)
-		k++;
-
-	if (k > high)
-		return -1;
-
-	return (cmpf(list[low], list[k]) >= 0)?low:k;
-}
-
-
 static void
 _s_vector_qsort(spointer list[], int low, int high, sc_compf_t cmpf)
 {
