@@ -1,7 +1,13 @@
 /**
- * $Id: tester.c,v 1.9 2004/07/10 17:04:48 jklein Exp $
+ * $Id: tester.c,v 1.11 2004/07/22 17:27:56 jklein Exp $
  * $Author: jklein $
  * $Log: tester.c,v $
+ * Revision 1.11  2004/07/22 17:27:56  jklein
+ * few changes in stack.h
+ *
+ * Revision 1.10  2004/07/11 04:06:07  jklein
+ * fixed s_vector_sort.
+ *
  * Revision 1.9  2004/07/10 17:04:48  jklein
  * Added few function to sxarray_t.
  *
@@ -46,8 +52,8 @@
 #include "scale/graphviz.h"
 
 
-#define FUNC_START() printf("[%s] {\n", __func__)
-#define FUNC_END()   printf("}\n");
+#define FUNC_START() printf("* %s\n", __func__)
+#define FUNC_END()   
 
 typedef int (*testfunc)(void);
 
@@ -626,9 +632,9 @@ test_heap()
 
 	assert(s_heap_size(heap) == 6);
 
-	sbuffer_t *graphbuf = s_heap_graphviz(heap);
-	printf("%s\n", graphbuf->string);
-	s_buffer_free(graphbuf);
+	sbuffer_t *gbuf = s_heap_graphviz(heap);
+	printf("%s\n", gbuf->string);
+	s_buffer_free(gbuf);
 
 	assert(strcmp(s_heap_pop(heap), "F") == 0);
 	assert(strcmp(s_heap_pop(heap), "E") == 0);
@@ -642,6 +648,7 @@ test_heap()
 	assert(s_heap_size(heap) == 0);
 	
 	s_heap_free(heap);
+
 	FUNC_END();
 	return 1;
 }
@@ -661,23 +668,38 @@ test_btree(void)
 	s_btree_add(btree, "b", "B");
 	s_btree_add(btree, "d", "D");
 	s_btree_add(btree, "e", "E");
-	assert(s_btree_size(btree) == 5);
+	s_btree_add(btree, "f", "E");
+	s_btree_add(btree, "g", "E");
+	s_btree_add(btree, "h", "E");
+	s_btree_add(btree, "i", "E");
+	s_btree_add(btree, "j", "E");
+	s_btree_add(btree, "k", "E");
+	assert(s_btree_size(btree) == 11);
+
 
 	assert(strcmp(s_btree_get(btree, "a"), "A") == 0);
 	assert(strcmp(s_btree_get(btree, "b"), "B") == 0);
 	assert(strcmp(s_btree_get(btree, "c"), "C") == 0);
 	assert(strcmp(s_btree_get(btree, "d"), "D") == 0);
 	assert(strcmp(s_btree_get(btree, "e"), "E") == 0);
-
-	sbuffer_t *gbuf = s_btree_graphviz(btree);
-	printf("%s\n", gbuf->string);
-	s_buffer_free(gbuf);
+	assert(strcmp(s_btree_get(btree, "f"), "E") == 0);
+	assert(strcmp(s_btree_get(btree, "g"), "E") == 0);
+	assert(strcmp(s_btree_get(btree, "h"), "E") == 0);
+	assert(strcmp(s_btree_get(btree, "i"), "E") == 0);
+	assert(strcmp(s_btree_get(btree, "j"), "E") == 0);
+	assert(strcmp(s_btree_get(btree, "k"), "E") == 0);
 
 	assert(strcmp(s_btree_remove(btree, "a"), "A") == 0);
 	assert(strcmp(s_btree_remove(btree, "b"), "B") == 0);
 	assert(strcmp(s_btree_remove(btree, "c"), "C") == 0);
 	assert(strcmp(s_btree_remove(btree, "d"), "D") == 0);
 	assert(strcmp(s_btree_remove(btree, "e"), "E") == 0);
+	assert(strcmp(s_btree_remove(btree, "f"), "E") == 0);
+	assert(strcmp(s_btree_remove(btree, "g"), "E") == 0);
+	assert(strcmp(s_btree_remove(btree, "h"), "E") == 0);
+	assert(strcmp(s_btree_remove(btree, "i"), "E") == 0);
+	assert(strcmp(s_btree_remove(btree, "j"), "E") == 0);
+	assert(strcmp(s_btree_remove(btree, "k"), "E") == 0);
 	assert(s_btree_size(btree) == 0);
 
 	{
@@ -735,6 +757,7 @@ main(int argc, char *argv[])
 				return EXIT_FAILURE;
 			}
 			else {
+				printf("contains error\n");
 				has_error = 1;
 			}
 		}
